==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
export let ToolCommandEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandEventArgsDescriptionMetadata.a == null) {
                ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolCommandEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolCommandEventArgsDescriptionMetadata.a);
            ToolCommandDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Command", "ExportedType:ToolCommand");
        }
        static d(a) {
            ToolCommandEventArgsDescriptionMetadata.b(a);
            a.ad("ToolCommandEventArgs", () => new ToolCommandEventArgsDescription());
            a.ac("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
        }
    }
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolCommandEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandDescriptionMetadata } from "./ToolCommandDescriptionMetadata";
import { ToolCommandEventArgsDescription } from "./ToolCommandEventArgsDescription";
/**
 * @hidden
 */
export let ToolCommandEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandEventArgsDescriptionMetadata.a == null) {
                ToolCommandEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandEventArgsDescriptionMetadata.c(ToolCommandEventArgsDescriptionMetadata.a);
            }
            if (a.k(ToolCommandEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolCommandEventArgsDescriptionMetadata.a);
            ToolCommandDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("Command", "ExportedType:ToolCommand");
            a.item("CloseOnExecute", "Boolean");
        }
        static d(a) {
            ToolCommandEventArgsDescriptionMetadata.b(a);
            a.ae("ToolCommandEventArgs", () => new ToolCommandEventArgsDescription());
            a.ad("ToolCommandEventArgs", ToolCommandEventArgsDescriptionMetadata.a);
        }
    }
    ToolCommandEventArgsDescriptionMetadata.$t = markType(ToolCommandEventArgsDescriptionMetadata, 'ToolCommandEventArgsDescriptionMetadata');
    ToolCommandEventArgsDescriptionMetadata.a = null;
    return ToolCommandEventArgsDescriptionMetadata;
})();
